
function ArkInventory.TooltipItemID( h )
	local id, suffix = ArkInventory.ItemStringDecode( h )
	if id ~= 0 then
		return string.format( "%s:%s", id, suffix )
	end
end

function ArkInventory.TooltipAddCustom( frame )
	
	--ArkInventory.PrintPlus( { "TooltipAddCustom ", TOOLTIP_UPDATE_TIME } )
	
	if ArkInventory.Global.Mode.Combat then
		return
	end
	
	if not frame["GetItem"] then
		return
	end
	
	if ArkInventory.db.account.option.tooltip.add.vendor then
		ArkInventory.TooltipVendorAdd( frame )
	end
	
	if ArkInventory.db.account.option.tooltip.add.count then
		ArkInventory.TooltipItemCountAdd( frame )
	end

end

function ArkInventory.TooltipItemCountAdd( frame )
	
	--ArkInventory.PrintPlus( { "TooltipAddCustom ", TOOLTIP_UPDATE_TIME } )
	
	local _, search_id = frame:GetItem()
	search_id = ArkInventory.TooltipItemID( search_id )
	if not search_id then
		return
	end
	
	if ArkInventory.Global.Cache.Tooltip[search_id] == nil then
		ArkInventory.Global.Cache.Tooltip[search_id] = ArkInventory.TooltipItemCountGet( search_id )
	end

	local tc = ArkInventory.db.account.option.tooltip.colour.count
	frame:AddLine( ArkInventory.Global.Cache.Tooltip[search_id], tc.r, tc.g, tc.b, 0 )
	frame:Show()

end

function ArkInventory.TooltipItemCountGet( search_id )
	
	local r = GetRealmName()
	local f = UnitFactionGroup( "player" )

	local apd = ArkInventory.db.account.player.data	
	local item_count_total = 0
	local character_count_total = 0
	local entry_character = { }

	for _, pd in ArkInventory.spairs( apd ) do

		local item_count_character = 0
		
		if pd.info.realm == r and pd.info.faction == f then
			
			local entry_location = { }

			local pl = ArkInventory.db.account.cache.realm[pd.info.realm].faction[pd.info.faction].character[pd.info.name]
			
			if pl and pl.location then
			
				local me = ""
				if pd.info.player_id == ArkInventory.Global.Me.player_id then
					me = ArkInventory.Localise["TOOLTIP_COUNT_ME"]
				end
			
				for l, ld in pairs( pl.location ) do
				
					local item_count_location = 0
				
					if ld.active then
						for b, bd in pairs( ld.bag ) do
							for s, sd in pairs( bd.slot ) do
								if sd.h and search_id == ArkInventory.TooltipItemID( sd.h ) then
									item_count_location = item_count_location + sd.count
								end
							end
						end
					end
					
					if item_count_location > 0 then
						tinsert( entry_location, string.format( "(%s %s)", ArkInventory.Global.Location[l].Name, item_count_location ) )
						item_count_character = item_count_character + item_count_location
					end
					
				end
				
				if item_count_character > 0 then
					tinsert( entry_character, string.format( "%s%s %s %s", me, pd.info.display3 or pd.info.name, item_count_character, table.concat( entry_location, ", " ) ) )
					character_count_total = character_count_total + 1
					item_count_total = item_count_total + item_count_character
				end
				
			end
			
		end
		
	end

	if item_count_total > 0 then
		if character_count_total > 1 then
			return string.format( "%s\nTotal %s", table.concat( entry_character, "\n" ), item_count_total )
		else
			return table.concat( entry_character, "\n" )
		end
	else
		return nil
	end
	
end


function ArkInventory.TooltipVendorAdd( frame )

	local _, search_id = frame:GetItem()
	search_id = ArkInventory.ItemStringDecode( search_id )
	if search_id == 0 then
		return
	end

	local price = ArkInventory.db.account.vendor[search_id]
	local tc = ArkInventory.db.account.option.tooltip.colour.vendor
	
	if price == nil then
		--frame:AddDoubleLine( ArkInventory.Localise["TOOLTIP_VENDOR"], ArkInventory.Localise["STATUS_NO_DATA"], tc.r, tc.g, tc.b, tc.r, tc.g, tc.b )
		return
	elseif price == 0 then
		if not ArkInventory.Global.Mode.Merchant then
			frame:AddLine( ITEM_UNSELLABLE, tc.r, tc.g, tc.b )
		end
	else
		ArkInventory.TooltipSetMoneyText( frame, price, ArkInventory.Localise["TOOLTIP_VENDOR"], tc.r, tc.g, tc.b )
	end

	frame:Show()
	
end


function ArkInventory.TooltipVendorScan()

	local moneyFrame = ArkInventory.Global.ScanTooltip:GetMoneyFrame()

	for _, bag_id in pairs( ArkInventory.Global.Location[ArkInventory.Const.Location.Bag].Bags ) do
	
		local bag_size = GetContainerNumSlots( bag_id )
	
		for slot_id = 1, bag_size do
		
			local h = GetContainerItemLink( bag_id, slot_id )
	
			if h then
				
				moneyFrame.staticMoney = 0
				-- hyperlinks do not work, can only use SetBagItem
				ArkInventory.Global.ScanTooltip:SetBagItem( bag_id, slot_id )
				local _, count = GetContainerItemInfo( bag_id, slot_id )
				local vendor = moneyFrame.staticMoney / count
				local id = ArkInventory.ItemStringDecode( h )
				ArkInventory.db.account.vendor[id] = vendor
				
				--ArkInventory.PrintPlus( { "bag=", bag_id, ", slot=", slot_id, ", copper=", vendor } )
			
			end
			
		
		end
	
	end

end
